@@ -1,5 +1,10 @@
 # plotting
 
+from ._plot_utils._get_default_matplotlib_figure_width_height import _get_default_matplotlib_figure_width_height as mpl_dimensions
+
+from ._scatter._ScatterPlot_Module import ScatterPlot
+from ._scatter._ScatterPlot_Module import _scatter as scatter
+
 from .fig_presets import single_fig_presets as presets
 from .make_data_gif import make_gif as make_gif
 
@@ -15,4 +20,8 @@ from ._set_minimal_ticks import _set_minimal_ticks as set_minimal_ticks
 
 # from ._histogram import _plot_histogram as histogram
 from ._modify_ax_spines import _modify_ax_spines as ax_spines
-from ._histogram_2d_component_plot import _histogram_2d_component_plot as hist2d_component_plot
\ No newline at end of file
+from ._histogram_2d_component_plot import (
+    _histogram_2d_component_plot as hist2d_component_plot,
+)
+
+from ._plot_correlation_heatmap import _plot_correlation_heatmap as correlation_heatmap
