@@ -1,4 +1,3 @@
-
 # package imports #
 # --------------- #
 import matplotlib
@@ -13,16 +12,14 @@ matplotlib.rcParams["font.sans-serif"] = "Arial"
 matplotlib.rcParams["font.family"] = "sans-serif"
 
 
-def _annotate_legend(ax, 
-    markerscale=3, fontsize=12, loc=2, **kwargs
-):
+def _annotate_legend(ax, markerscale=3, fontsize=12, loc=2, **kwargs):
 
     """"""
-    
+
     plt.legend(
         markerscale=markerscale,
         edgecolor="w",
         fontsize=fontsize,
         handletextpad=None,
         loc=loc,
-    )
\ No newline at end of file
+    )
