@@ -1,8 +1,7 @@
-
 # package imports #
 # --------------- #
-# import matplotlib
-# import matplotlib.font_manager
+import matplotlib
+import matplotlib.font_manager
 import matplotlib.pyplot as plt
 from matplotlib.gridspec import GridSpec
 from matplotlib.colorbar import Colorbar
@@ -14,10 +13,11 @@ from ._set_minimal_ticks import _set_minimal_ticks
 
 # # matplotlib presets #
 # # ------------------ #
-# font = {"size": 12}
-# matplotlib.rc(font)
-# matplotlib.rcParams["font.sans-serif"] = "Arial"
-# matplotlib.rcParams["font.family"] = "sans-serif"
+font = {"size": 12}
+matplotlib.rc(font)
+matplotlib.rcParams["font.sans-serif"] = "Arial"
+matplotlib.rcParams["font.family"] = "sans-serif"
+
 
 def _histogram_2d_component_plot(
     data,
@@ -26,7 +26,7 @@ def _histogram_2d_component_plot(
     histcolor="#63439C",
     histalpha=1,
     figsize=(7, 6),
-    title_fontsize=16, 
+    title_fontsize=16,
     label_fontsize=14,
     suptitle=False,
     save_path=False,
@@ -49,13 +49,10 @@ def _histogram_2d_component_plot(
 
     x_component_histogram = fig.add_subplot(gridspec[0, 1])
     x_component_bins = x_component_histogram.hist(
-        x_component,
-        bins=n_bins,
-        color=histcolor,
-        alpha=histalpha,
+        x_component, bins=n_bins, color=histcolor, alpha=histalpha,
     )
     x_component_histogram.grid(True)
-#     x_component_histogram.set_xticks([])
+    #     x_component_histogram.set_xticks([])
 
     y_component_histogram = fig.add_subplot(gridspec[1, 0])
     y_component_bins = y_component_histogram.hist(
@@ -85,20 +82,17 @@ def _histogram_2d_component_plot(
 
     histogram_2d.set_yticks([y_tick_min, y_tick_max])
     histogram_2d.yaxis.tick_right()
-#     y_component_histogram.set_yticks([])
+    #     y_component_histogram.set_yticks([])
 
     hist2d_spines = _modify_ax_spines(histogram_2d)
     hist2d_spines.set_color("grey")
-#     spines.delete(select_spines=["top", "right"])
+    #     spines.delete(select_spines=["top", "right"])
     hist2d_spines.set_position(position_type="axes", amount=-0.05)
     _set_minimal_ticks(histogram_2d, x_component, y_component)
-    
-#     for ax in [x_component_histogram, y_component_histogram, histogram_2d]:
-#         spines = _modify_ax_spines(ax)
-#         spines.delete()
-        
-    
-    
+
+    #     for ax in [x_component_histogram, y_component_histogram, histogram_2d]:
+    #         spines = _modify_ax_spines(ax)
+    #         spines.delete()
 
     hist2d_im = histogram_2d.imshow(data, cmap=cmap)
     colorbar_ax = fig.add_subplot(gridspec[1:, 2])
@@ -106,7 +100,7 @@ def _histogram_2d_component_plot(
     cb = Colorbar(ax=colorbar_ax, mappable=hist2d_im, ticklocation="right")
     cb.outline.set_visible(False)
     if suptitle:
-        plt.suptitle(suptitle, fontsize=title_fontsize, x=.55)
+        plt.suptitle(suptitle, fontsize=title_fontsize, x=0.55)
     plt.tight_layout()
     if save_path:
         out = plt.savefig(save_path)
