@@ -1,6 +1,6 @@
-
 import numpy as np
 
+
 def _set_minimal_ticks(ax, x, y, round_decimal=2):
 
     """"""
@@ -19,8 +19,12 @@ def _set_minimal_ticks(ax, x, y, round_decimal=2):
     )
     x_mid, y_mid = x_mid, y_mid
 
-    x_ticks = np.round(np.array([x_min, x_mid_low, x_mid, x_mid_high, x_max]), decimals=round_decimal)
-    y_ticks = np.round(np.array([y_min, y_mid_low, y_mid, y_mid_high, y_max]), decimals=round_decimal)
+    x_ticks = np.round(
+        np.array([x_min, x_mid_low, x_mid, x_mid_high, x_max]), decimals=round_decimal
+    )
+    y_ticks = np.round(
+        np.array([y_min, y_mid_low, y_mid, y_mid_high, y_max]), decimals=round_decimal
+    )
 
     ax.get_xaxis().set_ticks(x_ticks)
-    ax.get_yaxis().set_ticks(y_ticks)
\ No newline at end of file
+    ax.get_yaxis().set_ticks(y_ticks)
